==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-powermanagement/lxqt-powermanagement/lxqt-powermanagement_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Vide</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>En cours de décharge</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Totalement chargée</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>En charge</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Ion lithium (Li ion)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Lithium polymère (Li Po)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium fer phosphate</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Plomb et acide</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Nickel cadmium (Ni Cd)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Nickel metal hydride (NiMH)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Inconnue</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Batterie de PDA</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Batterie de système d&apos;alimentation secourue (UPS)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Batterie primaire</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Batterie de souris sans fil</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Batterie de clavier sans fil</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Batterie de clavier/souris sans fil</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Batterie d&apos;appareil photo</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>atterie de téléphonePhone battery</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Batterie d&apos;écran</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Batterie inconnue</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="22"/>
        <source>Battery Info</source>
        <translation>Information batterie</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Gestion de l&apos;énergie</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Température :</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Type :</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Statut :</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Énergie totale théorique :</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Énergie totale :</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Énergie actuellement :</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Taux d&apos;énergie :</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Technologie :</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Voltage :</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Vendeur :</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="47"/>
        <source>No battery!</source>
        <translation>Batterie absente !</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt ne trouve pas les données de la batterie - Gestion inactive</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="113"/>
        <source>Power low!</source>
        <translation>Énergie faible !</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="125"/>
        <source>Suspending in %n second(s)</source>
        <translation>Veille dans %n seconde(s)</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="128"/>
        <source>Hibernating in %n second(s)</source>
        <translation>Hibernation dans %n seconde(s)</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="131"/>
        <source>Shutting down in %n second(s)</source>
        <translation>Arrêt dans %n seconde(s)</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcher</name>
    <message>
        <location filename="../idlenesswatcher.cpp" line="50"/>
        <source>LXQt Idleness watcher failed to start</source>
        <translation>Le contrôleur d&apos;activité de LXQt n&apos;a pas pu démarrer</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="73"/>
        <source>D-Bus interface org.freedesktop.ScreenSaver is already registered</source>
        <translation>Interface DBus de org.freedesktop. L&apos;économiseur d&apos;écran est déjà enregistré</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="107"/>
        <source>The X11 Screensaver extension is not usable</source>
        <translation>L&apos;extension X11 Screensaver n&apos;est pas utilisable</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="114"/>
        <source>Configure...</source>
        <translation>Configuration ...</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="179"/>
        <source>ERROR: Screen unlocked</source>
        <translation>ERREUR : écran non verrouillé</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="181"/>
        <source>Locking program &quot;%1&quot; exited with error code %2</source>
        <translation>Sortie du programme de verrouillage &quot;%1&quot; avec code erreur %2</translation>
    </message>
    <message>
        <location filename="../idlenesswatcher.cpp" line="183"/>
        <source>Locking program &quot;%1&quot; crashed with error code %2</source>
        <translation>Plantage du programme de verrouillage &quot;%1&quot; avec code erreur %2</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="107"/>
        <source>Power Management</source>
        <translation>Gestion de l&apos;énergie</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="108"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Le programme de gestion d&apos;énergie de LXQt est exécuté pour la première fois.
Vous pouvez le configurer depuis Configuration ...</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="109"/>
        <source>Configure...</source>
        <translation>Configuration ...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="59"/>
        <source>Configure</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="61"/>
        <location filename="../trayicon.cpp" line="92"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="63"/>
        <source>Disable icon</source>
        <translation>Désactiver l'icône</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="93"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Gestion de l&apos;énergie de LXQt&lt;/b&gt;&lt;br/&gt;  - Gestion de l&apos;énergie del&apos;environnement Bureau LXQt&lt;/p&gt;&lt;p&gt;  Auteurs :&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - ainsi que d&apos;autres des projets Razor et LXQt&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="111"/>
        <source>LXQt Power Management info</source>
        <translation>Info de la gestion de l&apos;énergie de LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="112"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>L&apos;icône du tableau de bord peut être (re)activée dans  &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="114"/>
        <source>Configure now</source>
        <translation>Configurer maintenant</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-powermanagement/lxqt-powermanagement/lxqt-powermanagement_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../../../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Vide</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>En cours de décharge</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Totalement chargée</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>En charge</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Ion lithium (Li ion)</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Lithium polymère (Li Po)</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Lithium fer phosphate</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Plomb et acide</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Nickel cadmium (Ni Cd)</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Nickel metal hydride (NiMH)</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Inconnue</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Batterie de PDA</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Batterie de système d&apos;alimentation secourue (UPS)</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Batterie primaire</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Batterie de souris sans fil</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Batterie de clavier sans fil</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Batterie de clavier/souris sans fil</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Batterie d&apos;appareil photo</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>atterie de téléphonePhone battery</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Batterie d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Batterie inconnue</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../../../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../../../batteryinfodialog.cpp" line="22"/>
        <source>Battery Info</source>
        <translation>Information batterie</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Gestion de l&apos;énergie</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Température :</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Type :</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Statut :</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Énergie totale théorique :</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Énergie totale :</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Énergie actuellement :</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Taux d&apos;énergie :</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Technologie :</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Voltage :</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Vendeur :</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../../../batterywatcher.cpp" line="47"/>
        <source>No battery!</source>
        <translation>Batterie absente !</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="48"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt ne trouve pas les données de la batterie - Gestion inactive</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="113"/>
        <source>Power low!</source>
        <translation>Énergie faible !</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="125"/>
        <source>Suspending in %n second(s)</source>
        <translation type="unfinished">
            <numerusform>Veille dans %n seconde(s)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="128"/>
        <source>Hibernating in %n second(s)</source>
        <translation type="unfinished">
            <numerusform>Hibernation dans %n seconde(s)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="131"/>
        <source>Shutting down in %n second(s)</source>
        <translation type="unfinished">
            <numerusform>Arrêt dans %n seconde(s)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>IdlenessWatcher</name>
    <message>
        <source>LXQt Idleness watcher failed to start</source>
        <translation type="vanished">Le contrôleur d&apos;activité de LXQt n&apos;a pas pu démarrer</translation>
    </message>
    <message>
        <source>D-Bus interface org.freedesktop.ScreenSaver is already registered</source>
        <translation type="vanished">Interface DBus de org.freedesktop. L&apos;économiseur d&apos;écran est déjà enregistré</translation>
    </message>
    <message>
        <source>The X11 Screensaver extension is not usable</source>
        <translation type="vanished">L&apos;extension X11 Screensaver n&apos;est pas utilisable</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation type="vanished">Configuration ...</translation>
    </message>
    <message>
        <source>ERROR: Screen unlocked</source>
        <translation type="vanished">ERREUR : écran non verrouillé</translation>
    </message>
    <message>
        <source>Locking program &quot;%1&quot; exited with error code %2</source>
        <translation type="vanished">Sortie du programme de verrouillage &quot;%1&quot; avec code erreur %2</translation>
    </message>
    <message>
        <source>Locking program &quot;%1&quot; crashed with error code %2</source>
        <translation type="vanished">Plantage du programme de verrouillage &quot;%1&quot; avec code erreur %2</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../../../powermanagementd.cpp" line="108"/>
        <source>Power Management</source>
        <translation>Gestion de l&apos;énergie</translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="109"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Le programme de gestion d&apos;énergie de LXQt est exécuté pour la première fois.
Vous pouvez le configurer depuis Configuration ...</translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="110"/>
        <source>Configure...</source>
        <translation>Configuration ...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../../../trayicon.cpp" line="59"/>
        <source>Configure</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="61"/>
        <location filename="../../../trayicon.cpp" line="92"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="63"/>
        <source>Disable icon</source>
        <translation>Désactiver l&apos;icône</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="93"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Gestion de l&apos;énergie de LXQt&lt;/b&gt;&lt;br/&gt;  - Gestion de l&apos;énergie del&apos;environnement Bureau LXQt&lt;/p&gt;&lt;p&gt;  Auteurs :&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - ainsi que d&apos;autres des projets Razor et LXQt&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="111"/>
        <source>LXQt Power Management info</source>
        <translation>Info de la gestion de l&apos;énergie de LXQt</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="112"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>L&apos;icône du tableau de bord peut être (re)activée dans  &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="114"/>
        <source>Configure now</source>
        <translation>Configurer maintenant</translation>
    </message>
</context>
</TS>
